#############
API reference
#############

..
    to document functions, add them to __all__ in ../src/xsar/__init__.py

.. automodule:: xsar
    :members: open_dataset, product_info

Base classes
============
    .. autoclass:: BaseMeta
        :members:


    .. autoclass:: BaseDataset
        :members:

XSAR Meta classes
=================
    .. autoclass:: Sentinel1Meta
        :members:

    .. autoclass:: RadarSat2Meta
        :members:

    .. autoclass:: RcmMeta
        :members:

XSAR Dataset classes
====================
    .. autoclass:: Sentinel1Dataset
        :members:

    .. autoclass:: RadarSat2Dataset
        :members:

    .. autoclass:: RcmDataset
        :members:


